# Color map examples

# Libraries and data ----------------------------------------------------------

library(superheat)
library(tidyverse)

# edit the data
judges <- USJudgeRatings
# rename the columns
colnames(judges) <- c("contacts", "integrity", "demeanor", "diligence", 
                      "manag.", "prompt", "prep.", "familiar",
                      "oral", "written", "ability", "retention")

# take a random sample of 20 judges
set.seed(12789)
judges <- judges[sample(1:nrow(judges), 20), ]
# capitalize the first letter of each Judges name
capFirstLetter <- function(x) {
    s <- strsplit(x, " ")[[1]]
    paste(substring(s, 1, 1), 
          tolower(substring(s, 2, nchar(s) - 4)),
          substring(s, nchar(s) - 3, nchar(s)),
          sep="", collapse=" ")
}
# apply the capitalization to the Judge's names
rownames(judges) <- as.vector(sapply(rownames(judges), capFirstLetter))



# Quantile map ------------------------------------------------------

# make a color matrix for the text
judges_col <- matrix("black", ncol = ncol(judges), nrow = nrow(judges))
judges_col_quantile <- judges_col
judges_col_quantile[judges < 8.2] <- "white"

#png("../Figures/colormap_quantile.png", width = 1200, height = 600)
superheat(judges, 
          X.text = as.matrix(judges),
          X.text.col = judges_col_quantile,
          pretty.order.cols = TRUE, 
          pretty.order.rows = TRUE,
          column.title = "Characteristics",
          column.title.size = 8,
          row.title = "Judge",
          row.title.size = 8,
          # aesthetic options
          legend.breaks = 5:10, 
          grid.vline.col = "white",
          grid.hline.col = "white",
          left.label.size = 0.15,
          left.label.text.size = 6,
          bottom.label.text.size = 6,
          bottom.label.size = 0.08,
          legend.width = 3,
          legend.height = 0.2,
          legend.text.size = 20,
          title.size = 12)
#dev.off()

# Manual map ------------------------------------------------------------------

# hide high ratings (greater than 8)
judges_col_manipulated <- judges_col
judges_col_manipulated[judges < 7.4] <- "white"
#png("../Figures/colormap_manipulated.png", width = 1200, height = 600)
superheat(judges, 
          X.text = as.matrix(judges),
          X.text.col = judges_col_manipulated,
          pretty.order.cols = TRUE, 
          pretty.order.rows = TRUE,
          column.title = "Characteristics",
          column.title.size = 8,
          row.title = "Judge",
          row.title.size = 8,
          heat.pal.values = c(0, 0.2,
                              (9 - min(unlist(judges))) / max(unlist(judges)),
                              0.05 + (9 - min(unlist(judges))) / max(unlist(judges)),
                              1),
          # aesthetic options
          legend.breaks = 5:10, 
          grid.vline.col = "white",
          grid.hline.col = "white",
          left.label.size = 0.15,
          left.label.text.size = 6,
          bottom.label.text.size = 6,
          bottom.label.size = 0.08,
          legend.width = 3,
          legend.height = 0.2,
          legend.text.size = 20,
          title.size = 12)
# dev.off()

# Linear map ------------------------------------------------------------------
# linear color map
judges_col_linear <- judges_col
judges_col_linear[judges < 7.4] <- "white"
# png("../Figures/colormap_linear.png", width = 1200, height = 600)
superheat(judges, 
          X.text = as.matrix(judges),
          X.text.col = judges_col_linear,
          pretty.order.cols = TRUE, 
          pretty.order.rows = TRUE,
          column.title = "Characteristics",
          column.title.size = 8,
          row.title = "Judge",
          row.title.size = 8,
          heat.pal.values = c(0, 0.5, 1),
          # aesthetic options
          legend.breaks = 5:10, 
          grid.vline.col = "white",
          grid.hline.col = "white",
          left.label.size = 0.15,
          left.label.text.size = 6,
          bottom.label.text.size = 6,
          bottom.label.size = 0.08,
          legend.width = 3,
          legend.height = 0.2,
          legend.text.size = 20,
          title.size = 12)
# dev.off()

  
# Data distribution -----------------------------------------------------------

ggplot(data.frame(ratings = unlist(judges))) + 
  geom_histogram(aes(x = ratings, y = ..density..), 
                 col = "white", binwidth = 0.3) +
  theme_classic() +
  scale_y_continuous(expand = c(0, 0)) +
  theme(axis.title = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        axis.line = element_blank()) +
  geom_vline(xintercept = quantile(unlist(judges), c(0.25, 0.5, 0.75)), 
             col = "orange", size = 1.3)
# ggsave("judges_hist.png")

